@@ -2,6 +2,8 @@
 #define TRITON_CONVERSION_TRITONTOTRITONGPU_TRITONTOTRITONGPUPASS_H
 
 #include <memory>
+#include <optional>
+#include <string>
 
 namespace mlir {
 
@@ -10,14 +12,13 @@ template <typename T> class OperationPass;
 
 namespace triton {
 
-constexpr static char AttrNumWarpsName[] = "triton_gpu.num-warps";
-
 // Create the pass with numWarps passed from cl::opt.
 std::unique_ptr<OperationPass<ModuleOp>> createConvertTritonToTritonGPUPass();
 
 // Create the pass with numWarps set explicitly.
 std::unique_ptr<OperationPass<ModuleOp>>
-createConvertTritonToTritonGPUPass(int numWarps);
+createConvertTritonToTritonGPUPass(const std::string &target, int numWarps,
+                                   int threadsPerWarp = 32, int numCTAs = 1);
 
 } // namespace triton
 } // namespace mlir
