@@ -1,9 +1,6 @@
-//===- UtilityTest.cpp - Tests for
-// Utility----------------------------------===//
-//
-//===----------------------------------------------------------------------===//
+#include "triton/Dialect/Triton/IR/Utility.h"
 
-#include "triton/Analysis/Utility.h"
+#include "llvm/Support/Signals.h"
 #include <gtest/gtest.h>
 
 namespace mlir {
@@ -12,14 +9,14 @@ TEST(Analysis, reorder) {
   SmallVector<int> shape({10, 20, 30});
   {
     SmallVector<unsigned> order({2, 1, 0});
-    auto reordered = reorder<int>(shape, order);
+    auto reordered = triton::applyPermutation(shape, order);
     EXPECT_EQ(reordered[0], 30);
     EXPECT_EQ(reordered[1], 20);
     EXPECT_EQ(reordered[2], 10);
   }
   {
     SmallVector<unsigned> order({1, 0, 2});
-    auto reordered = reorder<int>(shape, order);
+    auto reordered = triton::applyPermutation(shape, order);
     EXPECT_EQ(reordered[0], 20);
     EXPECT_EQ(reordered[1], 10);
     EXPECT_EQ(reordered[2], 30);
@@ -27,3 +24,9 @@ TEST(Analysis, reorder) {
 }
 
 } // namespace mlir
+
+int main(int argc, char *argv[]) {
+  llvm::sys::PrintStackTraceOnErrorSignal(argv[0]);
+  testing::InitGoogleTest(&argc, argv);
+  return RUN_ALL_TESTS();
+}
